import React from 'react';
import { Menu, Input, Button, Pagination, Icon } from 'antd';
import Request from './util/Request';
import Utils from './util/Utils';
import Emitter from './util/Events';
require("./Main.css");
const SubMenu = Menu.SubMenu;
export default class DeviceListBar extends React.Component {
    layerList = [];
    filesResult = [];
    onSearch = false;
    locked = false;
    state = {
        deviceName: '',
        projectId: '',
    };
    isCheck = false;
    objPid = null;
    componentWillMount() {
        if (!this.locked) {
            this.state = { openKeys: [], current: [], projectId: this.props.projectId, pageCurrent: 1 };
            this.storeConfig = { start: 0, limit: 5 };
        }
    };
    setModuleStateFn;
    reloadDataCallFn;
    componentDidMount() {
        this.reloadDataCallFn = this.reloadDataCall.bind(this);
        Emitter.addListener('reloadListBar', this.reloadDataCallFn);
        this.setModuleStateFn = this.setModuleState.bind(this);
        Emitter.addListener('setModuleState', this.setModuleStateFn);
    };
    componentWillUnmount() {
        Emitter.removeListener('setModuleState', this.setModuleStateFn);
        Emitter.removeListener('reloadListBar', this.reloadDataCallFn);
        this.locked = true;
    };
    reloadDataCall(config) {
        if (!this.locked) {
            if (config == null) {
                this.reloadData({ projectId: this.state.projectId });
            } else {
                this.reloadData(config);
                this.setState({ projectId: config.projectId });
            }
        }
    }
    reloadData(config) {
        if (this.props.parent.onSearch) {
            if (Utils.isEmpty(config.deviceName)) {
                Utils.alert('请输入设备名称');
                return;
            }
            if (Utils.isNull(config.deviceName)) {
                Utils.alert('请输入设备名称');
                return;
            }
        }
        if (config.deviceName) {
            config.deviceName = config.deviceName.replace(/(^\s*)|(\s*$)/g, "");
        }
        let url = this.props.url;
        if (!Utils.isEmpty(config)) {
            Object.assign(this.storeConfig, config);
        }
        for (let key in this.storeConfig) {
            let v = this.storeConfig[key];
            if (!Utils.isEmpty(v))
                url += `&${key}=${v}`;
        }
        Request.get(url, null, this.getDataSuccess, this);
    };

    getDataSuccess(value) {
        if (!Utils.isSuccess(value)) {
            Emitter.emit('errorTips');
            return;
        }
        value.data.forEach(function (ele) {
            for (let i = 0; i < ele.children.length; i++) {
                ele.children[i].objType = ele.objType;
                ele.children[i].productName = ele.name;
            }
            this.layerList.push(ele.objType);
        }, this);
        this.filesResult = value.data;
        this.props.parent.layerList = this.layerList;
        this.getObjTypeList();
        if (this.props.parent.initialize) this.initializePage();
        this.onChangePage(1);
    };

    initializePage() {
        if (!this.locked) {
            let layer = window.earth.Api.Layers.getLayer(this.filesResult[0].objType);
            let firstModle = layer.getModel(this.filesResult[0].children[0].id);
            let firstPid = null;
            if (firstModle && firstModle.userData) {
                firstPid = firstModle.userData.pid;
            }
            let config = {
                id: this.filesResult[0].children[0].id,
                tableName: this.filesResult[0].children[0].tableName,
                objType: this.filesResult[0].objType,
                productName: this.filesResult[0].name,
                pid: firstPid
            }
            this.props.parent.setState({
                openKeys: [this.filesResult[0].objType],
                current: [this.filesResult[0].children[0].id]
            })
            Emitter.emit('reloadDetail', config);
            this.props.parent.initialize = false;
        }
    }
    getObjTypeList() {
        this.layerList.forEach(function (e) {
            Emitter.emit('setRightMenu', e);
        });
    };

    setModuleState(moduleState) {
        if (moduleState.isCheck == true) {
            this.isCheck = true;
            this.objPid = moduleState.objPid;

        } else {
            this.isCheck = false;
            this.objPid = moduleState.objPid;
        }
    };

    onChangeModuleName = (e) => {
        if (!this.locked) {
            this.setState({
                deviceName: e.target.value,
                isClear: true
            });
        }
    };

    onSearchModule() {
        this.props.parent.onSearch = true;
        this.reloadData({ projectId: this.state.projectId, deviceName: this.state.deviceName });
    };

    checkModule(e) {
        let item = {
            id: e.id,
            objType: e.objType,
        };
        Emitter.emit('findModule', item);
    };

    recursion(dataSource) {
        return (
            dataSource.map((menu, index) => {
                if (menu.children) {
                    return (
                        <SubMenu key={menu.objType} title={<span className='menuTitle'>{menu.name}</span>} className='gis-subMenu'>
                            {this.recursion(menu.children)}
                        </SubMenu>
                    )
                } else {
                    this.checkModule(menu);
                    return (<Menu.Item as={menu.tableName} key={menu.id} className='gis-menuItem' name={menu.productName} type={this.objPid}>
                        <span><Icon type="check" className={this.isCheck == true ? 'gis-isCheck' : 'gis-unCheck'} />
                            <span>{menu.name || "未知"}</span></span></Menu.Item>)
                }
            })
        )
    };

    onOpenChange = (openKeys) => {
        if (!this.locked) {
            const latestOpenKey = openKeys.find(key => this.props.parent.state.openKeys.indexOf(key) === -1);
            this.props.parent.setState({
                openKeys: [latestOpenKey],
            });
        }
    };

    handleClick = (e) => {
        let lastAddModel = this.props.parent.lastAddModel;
        if (!Utils.isEmpty(lastAddModel)) {
            let id = lastAddModel.id;
            let objType = lastAddModel.objType;
            let layer = window.earth.Api.Layers.getLayer(objType);
            layer.remove(layer.getModel(id));
        }
        if (!this.locked) {
            this.props.parent.setState({ current: [e.key] });
            let config = {
                id: e.key,
                tableName: e.item.props.as,
                objType: e.keyPath[e.keyPath.length - 1],
                productName: e.item.props.name,
                pid: e.item.props.type
            }
            Emitter.emit('reloadDetail', config);
        }
        this.props.parent.creatPop = false;
        earth.Api.Menus.clear()
    };

    onChangePage(pageCurrent) {
        if (!this.locked) {
            let resultPage = this.filesResult.slice(15 * (pageCurrent - 1), 15 * (pageCurrent - 1) + 15);
            this.setState({ resultPage: resultPage, pageCurrent: pageCurrent });
        }
    }
    clearInput() {
        this.setState({
            deviceName: "",
            isClear: false
        });
        this.storeConfig.deviceName = undefined;
        this.props.parent.onSearch = false;
        Emitter.emit('reloadListBar');
    }
    render() {
        const { deviceName } = this.state;
        const gisIcon = (
            <Icon onClick={this.clearInput.bind(this)} type="close-circle" theme="filled" style={{ color: '#ABD1FF' }} className={this.state.isClear == true ? "gis-input-suffix" : "gis-hide"} />
        );
        return (
            <div className='gis-searchGrid'>
                <div className='gis-searchDiv'>
                    <Input placeholder="输入设备名称搜索"
                        value={deviceName}
                        onChange={this.onChangeModuleName}
                        ref={node => this.moduleNameInput = node}
                        className='gis-searchInput'
                        suffix={gisIcon}
                    />

                    <Button
                        type="primary"
                        onClick={this.onSearchModule.bind(this)}
                        className='gis-searchButton'>
                        查询</Button>
                </div>
                <div className='gis-searchMenu'>
                    <span className='gis-listTitle'>设备列表</span>
                    <Menu
                        mode="inline"
                        theme="dark"
                        openKeys={this.props.parent.state.openKeys}
                        onOpenChange={this.onOpenChange}
                        onClick={this.handleClick}
                        selectedKeys={this.props.parent.state.current}
                        className='gis-listMenu'
                    >
                        {this.state ? this.recursion(this.state.resultPage || []) : null}
                    </Menu>
                    <Pagination
                        current={this.state.pageCurrent}
                        total={this.filesResult.length}
                        PageSize={15}
                        showTotal={total => `共${total}条`}
                        size='small'
                        onChange={this.onChangePage.bind(this)}
                        className='gis-listPagination'
                    />
                </div>

            </div>
        );
    };
}
