import React from "react";
import Utils from './util/Utils';
import EditModule from './EditModule';
import Emitter from './util/Events';
require("./Main.css");
export default class MapSite extends React.Component {
    exit = false;
    module = null;
    angle = null;
    state = {
        isEditModule: false,
    };
    findModuleFn;
    isAddModuleFn;
    setRightMenuFn;
    locked = false;
    componentWillMount() { };
    componentDidMount() {
        this.reloadMap(this.props);
        this.findModuleFn = this.findModule.bind(this);
        this.isAddModuleFn = this.isAddModule.bind(this);
        this.setRightMenuFn = this.setRightMenu.bind(this);
        Emitter.addListener('findModule', this.findModuleFn);
        Emitter.addListener('isAddModule', this.isAddModuleFn);
        Emitter.addListener('setRightMenu', this.setRightMenuFn);
    };
    componentWillUnmount() {
        Emitter.removeListener('findModule', this.findModuleFn);
        Emitter.removeListener('isAddModule', this.isAddModuleFn);
        Emitter.removeListener('setRightMenu', this.setRightMenuFn);
        this.locked = true;
    };

    setCfg(data) {
        let lookatPoint = null;
        if (data.lookat != "") {
            let result = data.lookat.split(",");
            lookatPoint = new earth.Api.Type.Point(result[0] * 1, result[1] * 1);
        } else {
            lookatPoint = {};
        }
        let cfg = {
            EngineIP: data.engineip,
            ResourcesIP: data.resourcesip,
            LookAt: lookatPoint,
            polarAngle: 88
        };
        Object.assign(cfg, { hideBGTile: true, hideSky: false });
        return cfg;
    };

    reloadMap(data) {
        let cfg = {
            dom: document.getElementById('glCanvas'),
            key: 'wSryzKApfH8y',
        };
        if (!window.earth) {
            window.earth = new Earth(cfg);
            cfg = this.setCfg(data);
            window.earth.changeConfig(cfg);
            this.listenModuleState();
        } else {
            cfg = this.setCfg(data);
            window.earth.changeConfig(cfg);
            this.listenModuleState();
        }
    };

    listenModuleState() {
        if (!this.locked && earth) {
            let me = this;
            window.earth.on('EarthFinish', function () {
                Emitter.emit('reloadListBar');
                if (earth) {
                    window.earth.Api.Inner.info((innerInfo) => {
                        Emitter.emit('getOptionData', innerInfo);
                    }, me);
                }
            });
            window.earth.on('MeshSaveState', function (geo) {
                me.getModulePosition(geo);
            });
            window.earth.on('MeshClick', function (geo) {
                console.log(geo);
            });
        }
    };

    createItem(text) {
        let menuDiv = document.createElement("div");
        menuDiv.className = 'gis-rightMenuItem';
        let menuSpan = document.createElement("span");
        menuSpan.innerHTML = text;
        menuSpan.style.cssText = `cursor: pointer;`;
        menuDiv.appendChild(menuSpan);
        return menuDiv;
    };

    setRightMenu(objType) {
        let backgroundDiv = document.createElement("div");
        backgroundDiv.className = 'gis-rightMenuDiv';
        let deleteDiv = this.createItem("删除设备");
        deleteDiv.event = { type: 'click', fn: this.deleteModel.bind(this) };
        backgroundDiv.appendChild(deleteDiv);
        earth.Api.Menus.setMenu(objType, backgroundDiv);
    };

    getModulePosition(geo) {
        let point = new window.earth.Api.Type.Point(geo.position.x, geo.position.y, geo.position.z, "3857");
        let modulePosition = point.clone().changeEPSGType('4326');
        Emitter.emit('saveModuleData', modulePosition);
    };

    findModule(data) {
        let objtype = data.objType;
        let layer = window.earth.Api.Layers.getLayer(objtype);
        if (layer == null) {
            let config = {
                isCheck: false,
                objPid: ""
            }
            Emitter.emit('setModuleState', config);
        } else {
            let e = layer.getModel(data.id);
            if (e) {
                let config = {
                    isCheck: true,
                    objPid: e.userData.pid
                }
                Emitter.emit('setModuleState', config);
            } else {
                let config = {
                    isCheck: false,
                    objPid: ""
                }
                Emitter.emit('setModuleState', config);
            }
        }
    }

    isExistModule(moduleData) {
        let objtype = moduleData.objType;
        if (!objtype) {
            Utils.alert("该类模型未配置！");
            return false;
        }
        let moduleLayer = window.earth.Api.Layers.getLayer(objtype);
        if (moduleLayer == null) {
            Utils.alert("该类模型未配置！");
            return false;
        } else {
            let data = moduleLayer.getModel(moduleData.id);
            if (data) {
                this.exit = true;
                this.module = data;
            }
        }
        return true;
    };

    isAddModule(moduleData) {
        if (!this.isExistModule(moduleData)) return;
        if (this.exit == true) {
            this.flyToModule(this.module);
        } else {
            this.addModule(moduleData);
        };
        this.module = null;
        this.exit = false;
    };

    addModule(ele) {
        if (!this.locked) {
            if (this.props.parent.setModel) {
                if (earth) {
                    this.props.parent.layerList.map((element) => {
                        window.earth.Api.Layers.setObjVisible(element, []);
                    });
                    this.props.parent.setModel = ele;
                }
            } else {
                setTimeout(() => {
                    if (earth) {
                        this.props.parent.layerList.map((element) => {
                            window.earth.Api.Layers.setObjVisible(element, []);
                        });
                        this.props.parent.setModel = ele;
                    }
                }, 1000);
            }
        }
    };

    flyToModule(geo) {
        if (!this.locked) {
            setTimeout(() => {
                if (earth) {
                    this.props.parent.layerList.map((element) => {
                        window.earth.Api.Layers.setObjVisible(element, [geo.userData.id]);
                        geo.changeColor('#fff900');
                    });
                    window.earth.Api.Camera.lookAt(geo.parent.userData.objType, geo.userData.id, false);
                }
            }, 1000);
            this.props.parent.lastAddModel = undefined;
            this.props.parent.setModel = undefined;
            this.props.parent.creatPop = false;
        }
    };

    deleteModel() {
        earth.Api.MeshInfo.doDelete();
        Emitter.emit('removeModuleData');
    };

    render() {
        return (
            <div id="glCanvas" className='gis-glCanvas'>
                {this.state.isEditModule == true ? <EditModule parent={this} /> : null}
            </div>
        );
    }
}
