import { message } from 'antd';
/**
 * 系统辅助类
 */
export default class Utils {
    /**
     * 判断是否为空
     * @param {字符串} str
     */
    static isEmpty(str) {
        if (str == null || str.length == 0)
            return true;
        return false;
    };

    static isNull(str) {
        if (str == "") return true;
        var regu = "^[ ]+$";
        var re = new RegExp(regu);
        return re.test(str);
    }

    /**
      * 判断小数点
      * */
    static isContains(str, substr) {
        if (!Utils.isEmpty(str)) {
            let string = str.toString()
            let last = string.substring(string.length - 1);
            return last.indexOf(substr) >= 0;
        }
    }

    /**
     * 获取token
     */
    static getToken() {
        return window.sessionStorage.getItem("ddmap_token");
    };
    /** 设置token */
    static setToken(token) {
        window.sessionStorage.setItem("ddmap_token", token);
    };
    /**
     * 提示框
     * @param {提示内容} m
     */
    static alert(m) {
        message.info(m);
    };
    /**
     * 失败
     * @param message
     */
    static error(m) {
        message.error(m);
    }

    /**
     * 警告
     * @param message
     */
    static warning(m) {
        message.warning(m);
    }

    static success(m) {
        message.success(m);
    }


    /**
     * 判断返回数据是否成功
     * @param {返回数据} data
     */
    static isSuccess(data) {
        if (data.errorCode) {
            message.error(data.message);
            return false;
        }
        return true;
    };

    /**
     * 获取secretKey
     */
    static getSecretKey() {
        return window.sessionStorage.getItem("ddmap_secretKey");
    };
    /** 设置secretKey */
    static setSecretKey(key) {
        window.sessionStorage.setItem("ddmap_secretKey", key);
    };
    /**
     * 参数说明：
     * s：要格式化的数字
     * n：保留几位小数
     * */
    static formatNum(s, n) {
        n = n > 0 && n <= 20 ? n : 2;
        s = parseFloat((s + "").replace(/[^\d\.-]/g, "")).toFixed(n) + "";
        let l = s.split(".")[0].split("").reverse(),
            r = s.split(".")[1];
        let t = "";
        for (let i = 0; i < l.length; i++) {
            t += l[i] + ((i + 1) % 3 == 0 && (i + 1) != l.length ? "," : "");
        }
        return t.split("").reverse().join("") + "." + r;
    }
    /** 获取UUID */
    static getUUID(len = 32) {
        let radix = 16;
        let chars = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz'.split('');
        let uuid = [], i;
        radix = radix || chars.length;
        if (len) {
            for (i = 0; i < len; i++) uuid[i] = chars[0 | Math.random() * radix];
        } else {
            var r;
            uuid[8] = uuid[13] = uuid[18] = uuid[23] = '-';
            uuid[14] = '4';
            for (i = 0; i < 36; i++) {
                if (!uuid[i]) {
                    r = 0 | Math.random() * 16;
                    uuid[i] = chars[(i == 19) ? (r & 0x3) | 0x8 : r];
                }
            }
        }
        return uuid.join('');
    };
}
